// Some standard utility functions for Dyynaform consumers

import { ValueTransformer } from './interfaces';

// Dropdown Modified Input - Starts With / Contains / Matches
const standardModifiers = ['Starts with', 'Contains', 'Matches'];
const standardTransformer: ValueTransformer = {
	inputFn: val => {
		let modifier = 'Starts with';
		if (/^%.*?%$/.test(val)) {
			modifier = 'Contains'
		} else if (/^[^%].*?[^%]$/.test(val)) {
			modifier = 'Matches'
		} else if (/^%.*/.test(val)) {
			modifier = 'Starts with';
		}
		const transformedVal = val.replace(/%/g, '').trim();
		return { modifier: modifier, value: transformedVal };
	},
	outputFn: (mod, val) => {
		let transformedValue;
		switch(mod) {
			case 'Starts with':
				transformedValue = `%${val}`;
				break;
			case 'Contains':
				transformedValue = `%${val}%`;
				break;
			case 'Matches':
			default:
				transformedValue = val;
				break;
		}
		return transformedValue;
	}
};

export { standardModifiers, standardTransformer };
